=========
line-plot
=========

A :class:`CGATReportPlugins.Plotter.LinePlot` displays :term:`numerical arrays`
as lines.

.. report:: Trackers.ArrayDataExample
   :render: line-plot
   :width: 200
   :layout: row

   A line plot

Options
=======

:class:`CGATReportPlugins.Plotter.LinePlot` understands the
:ref:`common plot options` and the following options:

.. glossary::
   :sorted:

   as-lines
      do not plot symbols, only lines

